/*
Copyright 2002-2006 The Members of the OSS through Java(TM) Initiative.
All rights reserved. Use is subject to license terms.
*/

package javax.oss;

/**
 * Every JVT&lt;ApplicationType&gt;Session Bean interface must derive from
 * the following base session interface. The base JVTSessionRemoteBusiness interface
 * provides a common set of operations shared by all the JVT Session Beans.
 * The implementation of the <CODE>JVTSessionRemoteBusiness</CODE> operations are mandatory.
 * <br>
 * The differences between remote and local clients are discussed in Sections
 * 5.2 through 5.4 of Enterprise JavaBeansTM Specification, Version 2.1.
 * 
 * 
 * @author OSS through Java Initiative, Vincent Perrot Sun Microsystems Inc.
 * @version 1.4
 * @since August 2005
 * @ossj:jvtsession 
 */
public interface JVTSessionRemoteBusiness {
    
    
    /**
     * Get the names of the optional operations supported by this JVT
     * Session Bean. The names of the optional operations are defined
     * in the <CODE>JVT&lt;ApplicationType&gt;SessionOptionalOps</CODE> interface as
     * defined by the API.
     *
     *
     * @return String array which contains the names of all the optional
     * operations supported by an implementation of a JVT Session Bean.
     *
     * @exception java.rmi.RemoteException
     */
    String[] getSupportedOptionalOperations( )
    throws java.rmi.RemoteException;
    
    /**
     * Get the Managed Entity types supported by a JVT Session Bean.
     *
     * @return String array which contains the fully qualified names of the leaf
     * node interfaces representing the supported managed entity types.
     * Note that it is not the implementation class name that is returned.
     * @exception java.rmi.RemoteException
     */
    
    String[] getManagedEntityTypes()
    throws java.rmi.RemoteException;
    
    /**
     * Get the Event Type names supported by the JVT Session Bean
     *
     * @return String array which contains the fully qualified names of the
     * leaf node interfaces representing the supported event types.
     * @exception java.rmi.RemoteException
     */
    //Get the Event Type Names supported by the Session Component
    String[] getEventTypes()
    throws java.rmi.RemoteException;
    
    /**
     * Get the EventPropertyDescriptor associated with an event type name.
     *
     * @param eventType fully qualified name of the leaf node Event interface.
     * @return EventPropertyDescriptor which can be used to discover the
     * filterable properties of the specified event type.
     * @exception javax.oss.OssIllegalArgumentException unknown or unsupported
     * event type.
     * @exception java.rmi.RemoteException
     */
    
    EventPropertyDescriptor getEventDescriptor(String eventType)
    throws javax.oss.OssIllegalArgumentException , java.rmi.RemoteException;
    
    
    
    /**
     * Create a Value Type object for a specific Managed Entity type.
     * Not to be confused with the creation of a Managed Entity.
     * The Session Bean is used as a factory for the creation of
     * Value Types.
     *
     * @param valueType fully qualified name of the leaf managed entity value
     * interface.
     * @return managed entity value object of the specified type.
     * @exception javax.oss.OssIllegalArgumentException unknown or unsupported
     * managed entity value type.
     * @exception java.rmi.RemoteException
     */
    
    ManagedEntityValue makeManagedEntityValue( String valueType)
    throws javax.oss.OssIllegalArgumentException, java.rmi.RemoteException;
    
    /**
     * Create a UpdateProcedureValue Instance matching a Update Procedure type name.
     * The Session Bean is used as a factory for the creation of
     * Update Procedure values.
     *
     * @param type fully qualified name of the leaf node UpdateProcedureValue interface.
     * @return Update Procedure value object of the specified type.
     * @exception javax.oss.OssIllegalArgumentException unknown or unsupported
     * Update Procedure type.
     * @exception java.rmi.RemoteException
     */
    UpdateProcedureValue makeUpdateProcedureValue(String type)
    throws javax.oss.OssIllegalArgumentException ,java.rmi.RemoteException;
    
    /**
     * Executes the given update procedure. (null is not a vlid argument for this method)
     *
     * @param updateValue a UpdateProcedureValue object representing the Update Procedure to be performed.
     * @return a UpdateProcedureResponse resulting from the Update Procedure execution.
     * @exception javax.oss.OssIllegalArgumentException unsupported Update Procedure value type.
     * @exception java.rmi.RemoteException
     *
     * @ossj:nillableField name=methodReturnValue value=true
     * @ossj:minOccursField name=methodReturnValue value=0
     * @ossj:minOccursField name=updateValue value=0
     */
    UpdateProcedureResponse update(UpdateProcedureValue updateValue)
    throws javax.oss.OssIllegalArgumentException ,java.rmi.RemoteException;
    
    /**
     * Get the UpdateProcedure type names supported by a JVT Session Bean
     *
     * @return String array which contains the fully qualified names of the leaf
     * node interfaces representing the supported update procedure value types,
     * i.e., interfaces which extend UpdateProcedureValue.
     * @exception java.rmi.RemoteException
     */
    
    String[] getUpdateProcedureTypes()
    throws java.rmi.RemoteException;
    
    /**
     * Query multiple Entities using a NamedQueryValue. (null is not a vlid argument for this method)
     *
     * @param namedQuery a NamedQueryValue object representing the query.
     * @return a NamedQueryResponse used to extract the results of the query.
     * @exception javax.oss.OssIllegalArgumentException unsupported named query value type.
     * @exception java.rmi.RemoteException
     *
     * @ossj:nillableField name=methodReturnValue value=true
     * @ossj:minOccursField name=methodReturnValue value=0
     * @ossj:minOccursField name=namedQuery value=0
     */
    NamedQueryResponse query(NamedQueryValue namedQuery)
    throws javax.oss.OssIllegalArgumentException, java.rmi.RemoteException;
    
    /**
     * Get the Named Query type names supported by a JVT Session Bean
     *
     * @return String array which contains the fully qualified names of the leaf
     * node interfaces representing the supported named query value types,
     * i.e., interfaces which extend NamedQueryValue.
     * @exception java.rmi.RemoteException
     */
    String[] getNamedQueryTypes() 
    throws java.rmi.RemoteException;
    
    /**
     * Create a NamedQueryValue Instance matching a Named Query type name.
     * The Session Bean is used as a factory for the creation of
     * named query values.
     *
     * @param type fully qualified name of the leaf node NamedQueryValue interface.
     * @return query value object of the specified type.
     * @exception javax.oss.OssIllegalArgumentException unknown or unsupported
     * named query type.
     * @exception java.rmi.RemoteException
     */
    NamedQueryValue makeNamedQueryValue(String type) 
    throws javax.oss.OssIllegalArgumentException,java.rmi.RemoteException;
}

