/*
Copyright 2002-2005 The Members of the OSS through Java(TM) Initiative.
All rights reserved. Use is subject to license terms.
*/

package javax.oss.util;

import java.util.Calendar;
import javax.naming.Name;

/**
 * This interface is used to capture the who, when and where a system interaction occurred.
 * javax.naming.Name is used to identify the who and the where; the when is typed as 
 * java.util.Calendar.
 *
 * @author OSS through Java Initiative, Dave Raymer Motorola Inc ,Vincent Perrot Sun Microsystems Inc.
 * @since   September 2005
 * @version 1.2
 * @ossj:complexdata
 */
public interface InteractionRecord extends Cloneable, java.io.Serializable{
    
    /**
     * Accessor for the id of the system from which the interaction occurred.
     *
     * @return the name of the system from which the interaction occurred.  
     */
    public Name getSystemId();
    
    /**
     * Accessor for the id of the user that initiated the interation.
     *
     * @return the name of the user who performed the action.
     */
    public Name getUserId();
    
    /**
     * Accessor for the time at which the interaction occurred.
     *
     * @return the time of the interaction, as a Calendar.
     */
    public Calendar getTime();
    
    /**
     * Mutator for the system id from which the interaction occurred.
     *
     * @param name the name of the system
     */
    public void setSystemId( Name name);
    
    /**
     * Mutator for the id of the user that initiated the action.
     *
     * @param name the name of the user
     */
    public void setUserId( Name name);
    
    /**
     * Mutator for the time at which the system interaction occurred.
     *
     * @param calendar the time of the system interaction, as a calendar instance.
     */
    public void setTime( Calendar calendar);
    
    /** Deep Copy
    *
    * @return an <CODE>Object</CODE> - clone
    */
   public Object clone();    
}
