/*
Copyright 2002-2006 The Members of the OSS through Java(TM) Initiative.
All rights reserved. Use is subject to license terms.
*/
package ossj.common.ex;

import com.infomodel.MplsVpnServiceValue;
import ossj.common.AttributeManager;
import ossj.common.Utils;


/**
 * An implementation class for the <CODE>ossj.common.ex.MplsVpnCreateEvent</CODE> interface.  
 * 
 * @see javax.oss.AttributeAccess
 * 
 * @see ossj.common.ex.MplsVpnCreateEvent
 * 
 * @see javax.oss.Event
 * 
 * @author OSS through Java(tm) Initiative, Vincent Perrot Sun Microsystems Inc.
 * @version 1.3 
 * @since January 2006 
 */


public class MplsVpnCreateEventImpl
extends ossj.common.EventImpl
implements MplsVpnCreateEvent
{ 

    /**
     * Constructs a new MplsVpnCreateEventImpl with empty attributes.
     * 
     */

    public MplsVpnCreateEventImpl() {
        super();
        initAttributeTypes();
    }

    /**
     * Constructs a new MplsVpnCreateEventImpl with the given Application DN.
     * @param applicationDN, the string representing the application DN
     *
     */


    MplsVpnCreateEventImpl(String applicationDN){
        super(applicationDN); 
    }


    private static final String[] attributeNames = {
        MplsVpnCreateEvent.MPLS_VPN_SERVICE
    };

    private static final String[] settableAttributeNames = {
        MplsVpnCreateEvent.MPLS_VPN_SERVICE
    };

    //
    // Configuration of AttributeManager and AttributeAccess
    //
    protected void addAttributesTo(AttributeManager anAttributeManager) {
        if (MplsVpnCreateEventImpl.attributeNames != null) {
            anAttributeManager.addAttributes(this.attributeNames);
            super.addAttributesTo(anAttributeManager);
        }
    }

    protected void configureAttributes(AttributeManager anAttributeManager) {
        if (MplsVpnCreateEventImpl.settableAttributeNames != null) {
            anAttributeManager.setSettableAttributes(MplsVpnCreateEventImpl.settableAttributeNames);
            super.configureAttributes(anAttributeManager);
        }
    }

    /**
     * Holds the Attribute manager that manage the optional fields
    */
    private static AttributeManager attributemanager = null;

    protected AttributeManager getAttributeManager() {
        return attributemanager;
    }
    protected AttributeManager makeAttributeManager() {
        attributemanager = new AttributeManager();
        return attributemanager;
    }

    /**
     * Init the Map Attribute Name/Attribute Type
     * Init the enumeration Map
     */
    protected void initAttributeTypes(){
        String[] list = new String[1];
        list[0] = "com.infomodel.MplsVpnServiceValue";
        addAttributeTypes("mplsVpnService", list);
    }

    private com.infomodel.MplsVpnServiceValue _mplsvpncreateeventimpl_mplsVpnService = null;


    /**
     * Changes the mplsVpnService to be equal to the given argument.
     * 
     * This method support a null argument.
     * 
     * @param value the new mplsVpnService for this object.
     * @exception java.lang.IllegalArgumentException - Is thrown to report
     * that a bad argument was provided to the method.
    */

    public void setMplsVpnService(com.infomodel.MplsVpnServiceValue value)
    throws java.lang.IllegalArgumentException    {
        setDirtyAttribute(MplsVpnCreateEvent.MPLS_VPN_SERVICE);
        _mplsvpncreateeventimpl_mplsVpnService = value;
    }


    /**
     * Returns this MplsVpnCreateEventImpl's mplsVpnService
     * 
     * @return the mplsVpnService
     * 
    */

    public com.infomodel.MplsVpnServiceValue getMplsVpnService()
    throws java.lang.IllegalStateException {
        checkAttribute(MplsVpnCreateEvent.MPLS_VPN_SERVICE);
        return _mplsvpncreateeventimpl_mplsVpnService;
    }

    /**
     * Creates a new object of the same class and with the same contents as this object.
     * @return a clone of this instance.
    */
    public Object clone() {
        MplsVpnCreateEvent val = null;
            val = (MplsVpnCreateEvent)super.clone();

            if( isPopulated(MplsVpnCreateEvent.MPLS_VPN_SERVICE)) {
                if( this.getMplsVpnService()!=null) 
                    val.setMplsVpnService((com.infomodel.MplsVpnServiceValue)((com.infomodel.MplsVpnServiceValue) this.getMplsVpnService()).clone());
                else
                    val.setMplsVpnService( null );
            }

            return val;
    }

    /**
     * Checks whether two MplsVpnCreateEvent are equal.
     * The result is true if and only if the argument is not null 
     * and is an MplsVpnCreateEvent object that has the arguments.
     * 
     * @param value the Object to compare with this MplsVpnCreateEvent
     * @return if the objects are equal; false otherwise.
     */

    public boolean equals (Object value) {
        if ( this == value ){ return true;}
        if ( (value != null) && ( value instanceof MplsVpnCreateEvent)) {
            MplsVpnCreateEvent argVal = (MplsVpnCreateEvent) value;
            return Utils.compareAttributeAccess( this, argVal );
        }
        return false;
    }

}
