/*
Copyright 2002-2006 The Members of the OSS through Java(TM) Initiative.
All rights reserved. Use is subject to license terms.
*/
package ossj.common.cbe.customer;

import javax.oss.cbe.customer.CustomerKey;
import javax.oss.cbe.customer.CustomerValue;
import ossj.common.AttributeManager;
import ossj.common.Utils;


/**
 * An implementation class for the <CODE>javax.oss.cbe.customer.CustomerValue</CODE> interface.  
 * 
 * @see javax.oss.AttributeAccess
 * 
 * @see javax.oss.cbe.customer.CustomerValue
 * 
 * @see javax.oss.ManagedEntityValue
 * 
 * @author OSS through Java(tm) Initiative, Vincent Perrot Sun Microsystems Inc.
 * @version 1.3 
 * @since January 2006 
 */


public class CustomerValueImpl
extends ossj.common.cbe.party.PartyRoleValueImpl
implements CustomerValue
{ 

    /**
     * Constructs a new CustomerValueImpl with empty attributes.
     * 
     */

    public CustomerValueImpl() {
        super();
        setManagedEntityKeyInstance( new CustomerKeyImpl());
        initAttributeTypes();
    }

    private static final String[] attributeNames = {
        CustomerValue.CUSTOMER_RANK,
        CustomerValue.CUSTOMER_STATE
    };

    private static final String[] settableAttributeNames = {
        CustomerValue.CUSTOMER_RANK,
        CustomerValue.CUSTOMER_STATE
    };

    //
    // Configuration of AttributeManager and AttributeAccess
    //
    protected void addAttributesTo(AttributeManager anAttributeManager) {
        if (CustomerValueImpl.attributeNames != null) {
            anAttributeManager.addAttributes(this.attributeNames);
            super.addAttributesTo(anAttributeManager);
        }
    }

    protected void configureAttributes(AttributeManager anAttributeManager) {
        if (CustomerValueImpl.settableAttributeNames != null) {
            anAttributeManager.setSettableAttributes(CustomerValueImpl.settableAttributeNames);
            super.configureAttributes(anAttributeManager);
        }
    }

    /**
     * Holds the Attribute manager that manage the optional fields
    */
    private static AttributeManager attributemanager = null;

    protected AttributeManager getAttributeManager() {
        return attributemanager;
    }
    protected AttributeManager makeAttributeManager() {
        attributemanager = new AttributeManager();
        return attributemanager;
    }

    
    //==================================================================
    // FACTORIES AND ATTRIBUTE TYPE FOR ================================
    //==================================================================
    
    public javax.oss.cbe.customer.CustomerKey makeCustomerKey(){
        return (CustomerKey) makeManagedEntityKey();
    }

    /**
     * Init the Map Attribute Name/Attribute Type
     * Init the enumeration Map
     */
    protected void initAttributeTypes(){
        String[] list = new String[1];
        addEnumeration("customerState", "javax.oss.cbe.customer.CustomerState");
        list[0] = "java.lang.String";
        addAttributeTypes("customerRank", list);
    }

    private java.lang.String _customervalueimpl_customerRank = null;
    private java.lang.String _customervalueimpl_customerState = null;


    /**
     * Changes the customerKey to be equal to the given argument.
     * 
     * This method support a null argument.
     * 
     * @param value the new customerKey for this object.
     * @exception java.lang.IllegalArgumentException - Is thrown to report
     * that a bad argument was provided to the method.
    */

    public void setCustomerKey(javax.oss.cbe.customer.CustomerKey value)
    throws java.lang.IllegalArgumentException    {
        setPartyRoleKey(value);
    }


    /**
     * Returns this CustomerValueImpl's customerKey
     * 
     * @return the customerKey
     * 
    */

    public javax.oss.cbe.customer.CustomerKey getCustomerKey()
    throws java.lang.IllegalStateException {
        return (javax.oss.cbe.customer.CustomerKey)getPartyRoleKey();
    }

    /**
     * Changes the customerRank to be equal to the given argument.
     * 
     * This method support a null argument.
     * 
     * @param value the new customerRank for this object.
     * @exception java.lang.IllegalArgumentException - Is thrown to report
     * that a bad argument was provided to the method.
    */

    public void setCustomerRank(java.lang.String value)
    throws java.lang.IllegalArgumentException    {
        setDirtyAttribute(CustomerValue.CUSTOMER_RANK);
        _customervalueimpl_customerRank = value;
    }


    /**
     * Returns this CustomerValueImpl's customerRank
     * 
     * @return the customerRank
     * 
    */

    public java.lang.String getCustomerRank()
    throws java.lang.IllegalStateException {
        checkAttribute(CustomerValue.CUSTOMER_RANK);
        return _customervalueimpl_customerRank;
    }

    /**
     * Changes the customerState to be equal to the given argument.
     * 
     * This method support a null argument.
     * 
     * @param value the new customerState for this object.
     * @exception java.lang.IllegalArgumentException - Is thrown to report
     * that a bad argument was provided to the method.
    */

    public void setCustomerState(java.lang.String value)
    throws java.lang.IllegalArgumentException    {
        setDirtyAttribute(CustomerValue.CUSTOMER_STATE);
        _customervalueimpl_customerState = value;
    }


    /**
     * Returns this CustomerValueImpl's customerState
     * 
     * @return the customerState
     * 
    */

    public java.lang.String getCustomerState()
    throws java.lang.IllegalStateException {
        checkAttribute(CustomerValue.CUSTOMER_STATE);
        return _customervalueimpl_customerState;
    }

    /**
     * Creates a new object of the same class and with the same contents as this object.
     * @return a clone of this instance.
    */
    public Object clone() {
        CustomerValue val = null;
            val = (CustomerValue)super.clone();

            if( isPopulated(CustomerValue.CUSTOMER_RANK)) {
                if( this.getCustomerRank()!=null) 
                    val.setCustomerRank(((java.lang.String) new String( this.getCustomerRank())));
                else
                    val.setCustomerRank( null );
            }

            if( isPopulated(CustomerValue.CUSTOMER_STATE)) {
                if( this.getCustomerState()!=null) 
                    val.setCustomerState(((java.lang.String) new String( this.getCustomerState())));
                else
                    val.setCustomerState( null );
            }

            return val;
    }

    /**
     * Checks whether two CustomerValue are equal.
     * The result is true if and only if the argument is not null 
     * and is an CustomerValue object that has the arguments.
     * 
     * @param value the Object to compare with this CustomerValue
     * @return if the objects are equal; false otherwise.
     */

    public boolean equals (Object value) {
        if ( this == value ){ return true;}
        if ( (value != null) && ( value instanceof CustomerValue)) {
            CustomerValue argVal = (CustomerValue) value;
            return Utils.compareAttributeAccess( this, argVal );
        }
        return false;
    }

}
