/*
Copyright 2002-2006 The Members of the OSS through Java(TM) Initiative.
All rights reserved. Use is subject to license terms.
*/
package ossj.common.cbe.product.productoffering;

import javax.oss.cbe.product.productoffering.ProductCatalogKey;
import javax.oss.cbe.datatypes.TimePeriod;
import ossj.common.cbe.datatypes.TimePeriodImpl;
import javax.oss.cbe.product.productoffering.ProductCatalogValue;
import ossj.common.AttributeManager;
import ossj.common.Utils;


/**
 * An implementation class for the <CODE>javax.oss.cbe.product.productoffering.ProductCatalogValue</CODE> interface.  
 * 
 * @see javax.oss.AttributeAccess
 * 
 * @see javax.oss.cbe.product.productoffering.ProductCatalogValue
 * 
 * @see javax.oss.ManagedEntityValue
 * 
 * @author OSS through Java(tm) Initiative, Vincent Perrot Sun Microsystems Inc.
 * @version 1.3 
 * @since January 2006 
 */


public class ProductCatalogValueImpl
extends ossj.common.cbe.EntityValueImpl
implements ProductCatalogValue
{ 

    /**
     * Constructs a new ProductCatalogValueImpl with empty attributes.
     * 
     */

    public ProductCatalogValueImpl() {
        super();
        setManagedEntityKeyInstance( new ProductCatalogKeyImpl());
        initAttributeTypes();
    }

    private static final String[] attributeNames = {
        ProductCatalogValue.ID,
        ProductCatalogValue.TYPE,
        ProductCatalogValue.VALID_FOR
    };

    private static final String[] settableAttributeNames = {
        ProductCatalogValue.ID,
        ProductCatalogValue.TYPE,
        ProductCatalogValue.VALID_FOR
    };

    //
    // Configuration of AttributeManager and AttributeAccess
    //
    protected void addAttributesTo(AttributeManager anAttributeManager) {
        if (ProductCatalogValueImpl.attributeNames != null) {
            anAttributeManager.addAttributes(this.attributeNames);
            super.addAttributesTo(anAttributeManager);
        }
    }

    protected void configureAttributes(AttributeManager anAttributeManager) {
        if (ProductCatalogValueImpl.settableAttributeNames != null) {
            anAttributeManager.setSettableAttributes(ProductCatalogValueImpl.settableAttributeNames);
            super.configureAttributes(anAttributeManager);
        }
    }

    /**
     * Holds the Attribute manager that manage the optional fields
    */
    private static AttributeManager attributemanager = null;

    protected AttributeManager getAttributeManager() {
        return attributemanager;
    }
    protected AttributeManager makeAttributeManager() {
        attributemanager = new AttributeManager();
        return attributemanager;
    }

    public String[] attributeTypeForValidFor() {
        return attributeTypeFor("validFor");
    }

    
    //==================================================================
    // FACTORIES AND ATTRIBUTE TYPE FOR ================================
    //==================================================================
    
    public javax.oss.cbe.datatypes.TimePeriod makeTimePeriod(String type){
        if(type.equals("javax.oss.cbe.datatypes.TimePeriod") || type.equals("ossj.common.cbe.datatypes.TimePeriodImpl")) {
            return new TimePeriodImpl();
        } else {
            return null;
        }
    }

    public javax.oss.cbe.product.productoffering.ProductCatalogKey makeProductCatalogKey(){
        return (ProductCatalogKey) makeManagedEntityKey();
    }

    /**
     * Init the Map Attribute Name/Attribute Type
     * Init the enumeration Map
     */
    protected void initAttributeTypes(){
        String[] list = new String[1];
        list[0] = "javax.oss.cbe.datatypes.TimePeriod";
        addAttributeTypes("validFor", list);
        list[0] = "java.lang.String";
        addAttributeTypes("type", list);
        list[0] = "java.lang.String";
        addAttributeTypes("id", list);
    }

    private java.lang.String _productcatalogvalueimpl_id = null;
    private java.lang.String _productcatalogvalueimpl_type = null;
    private javax.oss.cbe.datatypes.TimePeriod _productcatalogvalueimpl_validFor = null;


    /**
     * Changes the id to be equal to the given argument.
     * 
     * This method support a null argument.
     * 
     * @param value the new id for this object.
     * @exception java.lang.IllegalArgumentException - Is thrown to report
     * that a bad argument was provided to the method.
    */

    public void setId(java.lang.String value)
    throws java.lang.IllegalArgumentException    {
        setDirtyAttribute(ProductCatalogValue.ID);
        _productcatalogvalueimpl_id = value;
    }


    /**
     * Returns this ProductCatalogValueImpl's id
     * 
     * @return the id
     * 
    */

    public java.lang.String getId()
    throws java.lang.IllegalStateException {
        checkAttribute(ProductCatalogValue.ID);
        return _productcatalogvalueimpl_id;
    }

    /**
     * Changes the productCatalogKey to be equal to the given argument.
     * 
     * This method support a null argument.
     * 
     * @param value the new productCatalogKey for this object.
     * @exception java.lang.IllegalArgumentException - Is thrown to report
     * that a bad argument was provided to the method.
    */

    public void setProductCatalogKey(javax.oss.cbe.product.productoffering.ProductCatalogKey value)
    throws java.lang.IllegalArgumentException    {
        setEntityKey(value);
    }


    /**
     * Returns this ProductCatalogValueImpl's productCatalogKey
     * 
     * @return the productCatalogKey
     * 
    */

    public javax.oss.cbe.product.productoffering.ProductCatalogKey getProductCatalogKey()
    throws java.lang.IllegalStateException {
        return (javax.oss.cbe.product.productoffering.ProductCatalogKey)getEntityKey();
    }

    /**
     * Changes the type to be equal to the given argument.
     * 
     * This method support a null argument.
     * 
     * @param value the new type for this object.
     * @exception java.lang.IllegalArgumentException - Is thrown to report
     * that a bad argument was provided to the method.
    */

    public void setType(java.lang.String value)
    throws java.lang.IllegalArgumentException    {
        setDirtyAttribute(ProductCatalogValue.TYPE);
        _productcatalogvalueimpl_type = value;
    }


    /**
     * Returns this ProductCatalogValueImpl's type
     * 
     * @return the type
     * 
    */

    public java.lang.String getType()
    throws java.lang.IllegalStateException {
        checkAttribute(ProductCatalogValue.TYPE);
        return _productcatalogvalueimpl_type;
    }

    /**
     * Changes the validFor to be equal to the given argument.
     * 
     * This method support a null argument.
     * 
     * @param value the new validFor for this object.
     * @exception java.lang.IllegalArgumentException - Is thrown to report
     * that a bad argument was provided to the method.
    */

    public void setValidFor(javax.oss.cbe.datatypes.TimePeriod value)
    throws java.lang.IllegalArgumentException    {
        setDirtyAttribute(ProductCatalogValue.VALID_FOR);
        _productcatalogvalueimpl_validFor = value;
    }


    /**
     * Returns this ProductCatalogValueImpl's validFor
     * 
     * @return the validFor
     * 
    */

    public javax.oss.cbe.datatypes.TimePeriod getValidFor()
    throws java.lang.IllegalStateException {
        checkAttribute(ProductCatalogValue.VALID_FOR);
        return _productcatalogvalueimpl_validFor;
    }

    /**
     * Creates a new object of the same class and with the same contents as this object.
     * @return a clone of this instance.
    */
    public Object clone() {
        ProductCatalogValue val = null;
            val = (ProductCatalogValue)super.clone();

            if( isPopulated(ProductCatalogValue.ID)) {
                if( this.getId()!=null) 
                    val.setId(((java.lang.String) new String( this.getId())));
                else
                    val.setId( null );
            }

            if( isPopulated(ProductCatalogValue.TYPE)) {
                if( this.getType()!=null) 
                    val.setType(((java.lang.String) new String( this.getType())));
                else
                    val.setType( null );
            }

            if( isPopulated(ProductCatalogValue.VALID_FOR)) {
                if( this.getValidFor()!=null) 
                    val.setValidFor((javax.oss.cbe.datatypes.TimePeriod)((javax.oss.cbe.datatypes.TimePeriod) this.getValidFor()).clone());
                else
                    val.setValidFor( null );
            }

            return val;
    }

    /**
     * Checks whether two ProductCatalogValue are equal.
     * The result is true if and only if the argument is not null 
     * and is an ProductCatalogValue object that has the arguments.
     * 
     * @param value the Object to compare with this ProductCatalogValue
     * @return if the objects are equal; false otherwise.
     */

    public boolean equals (Object value) {
        if ( this == value ){ return true;}
        if ( (value != null) && ( value instanceof ProductCatalogValue)) {
            ProductCatalogValue argVal = (ProductCatalogValue) value;
            return Utils.compareAttributeAccess( this, argVal );
        }
        return false;
    }

}
